pub struct BrowsePageRequest {
pub server: String,
pub session_id: Option<String>,
pub parent_node_key: Option<String>,
pub page_token: Option<String>,
pub page_size: u32,
pub refresh: bool,
}Expand description
Parameters for one browse-page request.
Fields
server: Stringsession_id: Option<String>parent_node_key: Option<String>page_token: Option<String>page_size: u32refresh: boolImplementations
Sourceimpl BrowsePageRequest
impl BrowsePageRequest
Sourcepub fn root(server: impl Into<String>, page_size: u32) -> Self
pub fn root(server: impl Into<String>, page_size: u32) -> Self
Open a new browse session and request its root page.
Sourcepub fn children(
server: impl Into<String>,
session_id: impl Into<String>,
parent_node_key: impl Into<String>,
page_size: u32,
) -> Self
pub fn children( server: impl Into<String>, session_id: impl Into<String>, parent_node_key: impl Into<String>, page_size: u32, ) -> Self
Request the first page beneath an already-discovered branch.
Sourcepub fn next(
server: impl Into<String>,
session_id: impl Into<String>,
parent_node_key: Option<String>,
page_token: impl Into<String>,
page_size: u32,
) -> Self
pub fn next( server: impl Into<String>, session_id: impl Into<String>, parent_node_key: Option<String>, page_token: impl Into<String>, page_size: u32, ) -> Self
Request the next page for a root or child browse.
Sourcepub fn with_refresh(self, refresh: bool) -> Self
pub fn with_refresh(self, refresh: bool) -> Self
Ask the gateway to bypass cached namespace metadata.